@@ -32,7 +32,7 @@ BASE_PROMPT = """You have an instance `env` with methods:
 - `env.send_keys(element, text)` sends `text` to element. Be mindful of special keys, like "enter" (use Keys.ENTER) and "tab" (use Keys.TAB).
 - `env.click(element)` clicks the WebElement. Use this instead of `element.click()`.
 - `env.wait(seconds)` waits for `seconds`.
-- `env.scroll(direction, iframe=None)` scrolls. Switches to `iframe` if given. `direction` can be "up", "down", "left", or "right". 
+- `env.scroll(direction, iframe=None)` scrolls. Switches to `iframe` if given. `direction` can be "up", "down", "bottom", "top", "left", or "right".
 - `env.get_llm_response(text)` asks AI about a string `text`.
 - `env.query_memory(prompt)` asks AI to query its memory of ALL the web pages it has browsed so far. Invoked with something like "Query memory".
 - `env.retrieve_information(prompt, entire_page=False)` returns a string, information from a page given a prompt. Use prompt="Summarize:" for summaries. Uses all the text if entire_page=True and only visible text if False. Invoked with commands like "retrieve", "find in the page", or similar.
@@ -53,16 +53,17 @@ The xpath for an element whose text is "text" is "//*[normalize-space() = 'text'
 The xpath of a text box is usually "//input|//div[@role = 'textarea']|//div[@role = 'textbox']".
 The xpath for a button is usually "//button|//div[@role = 'button']", but it may sometimes also be an anchor.
 
-Your code must obey the following constraints:
-1. Respect case sensitivity in the instructions.
-2. Does not call any functions besides those given above and those defined by the base language spec.
-3. Has correct indentation.
-4. Only write code. Do not write comments.
-5. Only do what I instructed you to do.
-
 INSTRUCTIONS:
 {instructions}
 
+Your code must obey the following constraints:
+- Only write code. Do not write comments.
+- Has correct indentation.
+- Respect case sensitivity in the instructions.
+- Does not call any functions besides those given above and those defined by the base language spec.
+- Only do what I instructed you to do.
+- You may not import any modules. You may not use any external libraries.
+
 OUTPUT: ```python"""
 
 PROMPT_TO_FIND_ELEMENT = """Given the HTML below, write the `value` argument to the Python Selenium function `env.find_elements(by='xpath', value=value)` to precisely locate the element.
@@ -79,7 +80,7 @@ class InstructionCompiler:
         self,
         instructions=None,
         base_prompt=BASE_PROMPT,
-        model="text-davinci-003",
+        model="gpt-3.5-turbo",
         use_compiled=True,
     ):
         """Initialize the compiler. The compiler handles the sequencing of
@@ -111,6 +112,7 @@ class InstructionCompiler:
 
         # Instance variables.
         self.model = model
+        logger.info(f"Using model {self.model}.")
         self.base_prompt = BASE_PROMPT
         self.prompt_to_find_element = PROMPT_TO_FIND_ELEMENT
         self.use_compiled = use_compiled
